#
# spec file for package python-dulwich
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if 0%{?suse_version} >= 1550
%bcond_without test
%else
%bcond_with test
%endif

%{?sle15_python_module_pythons}
%define oldpython python
Name:           python-dulwich
Version:        0.21.7
Release:        150600.1.3
Summary:        Pure-Python Git Library
License:        Apache-2.0 OR GPL-2.0-or-later
Group:          Development/Languages/Python
URL:            https://www.dulwich.io
Source0:        https://files.pythonhosted.org/packages/source/d/dulwich/dulwich-%{version}.tar.gz
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module setuptools >= 17.1}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
%if %{with test}
BuildRequires:  %{python_module Sphinx}
BuildRequires:  %{python_module fastimport}
BuildRequires:  %{python_module geventhttpclient}
BuildRequires:  %{python_module gevent}
BuildRequires:  %{python_module gpg}
BuildRequires:  %{python_module typing_extensions if %python-base < 3.8}
BuildRequires:  %{python_module urllib3 >= 1.24.1}
%if 0%{?suse_version} <= 1500
BuildRequires:  python-mock
%endif
%endif
Requires:       python-urllib3 >= 1.24.1
%if %{python_version_nodots} < 38
Requires:       python-typing_extensions
%endif
Requires(post): update-alternatives
Requires(preun):update-alternatives
Recommends:     python-fastimport
Recommends:     python-gpg
Obsoletes:      %{oldpython}-dulwich-doc < 0.20.5
%python_subpackages

%description
Simple Pure-Python implementation of the Git file formats and protocols. Dulwich
is the place where Mr. and Mrs. Git live in one of the Monty Python sketches.

%prep
%autosetup -p1 -n dulwich-%{version}

%build
export CFLAGS="%{optflags}"
%python_build

%install
%python_install
# Do not remove tests as they are reused by other packages
#%%python_expand rm -r %{buildroot}%{$python_sitearch}/dulwich/tests
%python_expand %fdupes %{buildroot}%{$python_sitearch}
%python_clone -a %{buildroot}%{_bindir}/dulwich
%python_clone -a %{buildroot}%{_bindir}/dul-receive-pack
%python_clone -a %{buildroot}%{_bindir}/dul-upload-pack

%check
%if %{with test}
%python_expand PYTHONPATH=%{buildroot}%{$python_sitearch} $python -m unittest dulwich.tests.test_suite
%endif

%post
%python_install_alternative dulwich
%python_install_alternative dul-receive-pack
%python_install_alternative dul-upload-pack

%postun
%python_uninstall_alternative dulwich
%python_uninstall_alternative dul-receive-pack
%python_uninstall_alternative dul-upload-pack

%files %{python_files}
%license COPYING
%doc NEWS README.rst
%python_alternative dulwich
%python_alternative dul-receive-pack
%python_alternative dul-upload-pack
%{python_sitearch}/*

%changelog
* Wed Dec  6 2023 dmueller@suse.com
- update to 0.21.7:
  * Fix NameError when encountering errors during HTTP operation.
  * Raise exception when default identity can't be found.
  * Add a dedicated exception class for unresolved
    deltas.
  * Support credentials in proxy URL. (Jelmer Vernooĳ, #1227)
  * Add ``dulwich.porcelain.for_each_ref``. (Daniele Trifirò)
* Mon Sep 18 2023 dmueller@suse.com
- update to 0.21.6:
  * index: Handle different stages of conflicted paths.
  * Improve LCA finding performance. (Kevin Hendricks)
  * client: Handle Content-Type with encoding set.
  * Only import _hashlib for type checking.
  * Update docs regarding building dulwich without c bindings
  * objects: Define a stricter return type for _parse_message
  * Raise GitProtocolError when encountering HTTP Errors in
  * HTTPGitClient.
* Mon May  8 2023 kastl@b1-systems.de
- add sle15_python_module_pythons
* Sun May  7 2023 dmueller@suse.com
- update to 0.21.5:
  * Be more tolerant to non-3-length tuple versions.
  * Support ``core.symlinks=false``.
  * Deprecate ``dulwich.objects.parse_commit``.
  * Fix fetching into MemoryRepo.
  * Support ``init.defaultBranch`` config.
  * Fix ``ObjectStore.iterobjects_subset()`` when
    hex shas are passed for objects that live in packs.
  * client: Handle absolute path as redirect location in HTTP
    client.
* Thu Feb 23 2023 dmueller@suse.com
- update to 0.21.3:
  * Add support for ``worktreeconfig`` extension.
  * Deprecate ``Commit.extra``; the Git project specifically
    discourages adding custom lines, and the contents of
    ``Commit.extra`` are unpredictable as contents
    may be different between different versions of Dulwich
    with support for different headers.
    ``Commit._extra`` still exists.
* Wed Feb  1 2023 expeehaa@outlook.com
- Add dependency typing_extension for Python versions <3.8.
* Thu Jan 19 2023 expeehaa@outlook.com
- Update to version 0.21.2.
  * Fix early file close bug in dulwich.pack.extend_pack. (@jelmer)
- Update to version 0.21.1.
  * Factor out dulwich.pack.extend_pack. (@jelmer)
- Update to version 0.21.0.
  * Pack internals have been significantly refactored, including significant low-level API changes.
    As a consequence of this, Dulwich now reuses pack deltas when
    communicating with remote servers, which brings a big boost to network performance. (@jelmer)
  * Add 'pack-refs' command. (@danchr)
  * Handle more errors when trying to read a ref (@danchr)
  * Allow for reuse of existing deltas while creating pack files (@stspdotname)
  * cli: fix argument parsing for pack-objects --stdout (@stspdotname)
  * cli: open pack-objects output files in binary mode to avoid write() error (@stspdotname)
  * Bump minimum python version to 3.7. (@jelmer)
  * honor no_proxy environment variable (#1098, @afaul)
  * In HTTP Git Client, allow missing Content-Type. (@jelmer)
  * Fix --pure builds (@jelmer, #1093)
  * Allow passing abbrev to describe (#1084, @nanonyme)
* Mon Nov 21 2022 expeehaa@outlook.com
- Update to version 0.20.50.
  * Fix Repo.reset_index. Previously, it instead took the union with the given tree. (Christian Sattler, #1072)
  * Add -b argument to dulwich clone. (Jelmer Vernooĳ)
  * On Windows, provide a hint about developer mode when creating symlinks fails due to a permission error. (Jelmer Vernooĳ, #1005)
  * Add new ObjectID type in dulwich.objects, currently just an alias for bytes. (Jelmer Vernooĳ)
  * Support repository format version 1. (Jelmer Vernooĳ, #1056)
  * Support \r\n line endings with continuations when parsing configuration files. (Jelmer Vernooĳ)
  * Fix handling of SymrefLoop in RefsContainer.setitem. (Dominic Davis-Foster, Jelmer Vernooĳ)
* Mon Sep 12 2022 dmueller@suse.com
- update to 0.20.46:
  * Apply insteadOf to rsync-style location strings
  * Drop use of certifi, instead relying on urllib3's default
  code to find system CAs.
  * Implement timezone parsing in porcelain.
  * Drop support for running without setuptools.
  * Ensure configuration is loaded when
  running "dulwich clone".
  * Build 32 bit wheels for Windows.
  * tests: Ignore errors when deleting GNUPG
  home directory. Fixes spurious errors racing
  gnupg-agent. Thanks, Matěj Cepl. Fixes #1000
  * config: Support closing brackets in quotes in section
  names. (Jelmer Vernooĳ, #10124)
  * Various and formatting fixes. (Kian-Meng Ang)
  * Document basic authentication in dulwich.porcelain.clone.
  * Flush before calling fsync, ensuring buffers
  are filled. (wernha)
  * Support GPG commit signing. (springheeledjack0)
  * Add python 3.11 support. (Saugat Pachhai)
  * Allow missing GPG during tests. (Jakub Kulík)
  * status: return posix-style untracked paths instead of nt-style paths on
  win32 (Daniele Trifirò)
  * Honour PATH environment when running C Git for testing.
  * Split out exception for symbolic reference loops.
  * Move various long-deprecated methods.
- drop rmtree-ignore-errors.patch (upstream)
* Tue Sep  6 2022 expeehaa@outlook.com
- Disable tests on Leap.
- Remove gevent and geventhttpclient from Recommends since they are only required for tests.
* Wed Aug 31 2022 mcepl@suse.com
- Adjust rmtree-ignore-errors patch according to upstream review.
* Fri Aug 19 2022 mcepl@suse.com
- Add rmtree-ignore-errors.patch to make shutil.rmtree to be more
  callous (gh#jelmer/dulwich#1000) and prevent thus the race
  condition in cleaning up after the tests.
* Mon Jul 25 2022 dmueller@suse.com
- update to 0.20.45:
  * Add basic ``dulwich.porcelain.submodule_list`` and ``dulwich.porcelain.submodule_add``
  * Fix reading of chunks in server. (Jelmer Vernooĳ, #977)
  * Support applying of URL rewriting using ``insteadOf`` / ``pushInsteadOf``.
* Sun Jun 19 2022 dmueller@suse.com
- update to 2.0.43:
  * Lazily import url2pathname.
  * Drop caching of full HTTP response. Attempt #2.
* Sun May 29 2022 dmueller@suse.com
- update to 0.20.42:
  * Drop ``RefsContainer.watch`` that was always flaky.
  * Fix wheel uploading, properly. (Ruslan Kuprieiev)
* Sun May 22 2022 expeehaa@outlook.com
- Update to version 0.20.40.
  Changelog: https://github.com/jelmer/dulwich/releases/tag/dulwich-0.20.40
  * Fix wheel uploading.
* Sat Mar 26 2022 dmueller@suse.com
- update to 0.20.35:
  * Document the ``path`` attribute for ``Repo``.
  * Add support for multivars in configuration.
  * Fix handling of escaped characters in ignore patterns.
  * Add ``dulwich.contrib.requests_vendor``. (epopcon)
  * Ensure git config is available in a linked working tree.
* Fri Feb  4 2022 dmueller@suse.com
- update to 0.20.32:
  * Properly close result repository during test.
* Sun Jan 23 2022 dmueller@suse.com
- update to 0.20.31:
  * Add GitClient.clone()
* Mon Jan 10 2022 dmueller@suse.com
- update to 0.20.30:
  * Support staging submodules.
  * Drop deprecated Index.iterblobs and iter_fresh_blobs.
  * Unify clone behaviour of ``Repo.clone`` and
  ``porcelain.clone``, and add branch parameter for
  clone.
  * Fix hook test on Mac OSX / Linux when dulwich is
  not installed system-wide.
  * Cope with gecos being unset.
  * Allow adding files to repository in pre-commit hook.
  * Raise SubmoduleEncountered in ``tree_lookup_path``.
* Sat Nov 13 2021 dmueller@suse.com
- update to 0.20.26:
  * Support os.PathLike arguments to Repo.stage()
  * Drop support for Python 3.5
  * Add ``dulwich.porcelain._reset_file``
  * Add ``Repo.unstage``
* Sat Oct 16 2021 dmueller@suse.com
- update to 0.20.25:
  * Fix ``dulwich`` script when installed via setup.py.
  * Make default file mask consistent
* Thu Aug 19 2021 bwiedemann@suse.com
- update to 0.20.24
  * https://github.com/dulwich/dulwich/commits/0.20.24
  * fix build after 2023 (boo#1102840)
  * config: disregard UTF-8 BOM when reading file
  * Split out a AbstractHTTPGitClient class
  * Set zip_safe=false
  * Add separate HTTPProxyUnauthorized exception
* Sun Jun  6 2021 dmueller@suse.com
- update to 0.20.23:
  * Fix installation of GPG during package publishing.
  * Prevent removal of refs directory when the last ref is
    deleted.
  * Fix filename: MERGE_HEADS => MERGE_HEAD.
  * For ignored directories, porcelain.add and porcelain.status now only return
    the path to directory itself in the list of ignored paths. Previously, paths
    for all files within the directory would also be included in the list.
  * Provide depth argument to ``determine_wants``.
  * Various tag signature handling improvements.
  * Add separate Tag.verify().  (Peter Rowlands)
  * Add support for version 3 index files. (Jelmer Vernooĳ)
  * Fix autocrlf=input handling. (Peter Rowlands, Boris Feld)
  * Attempt to find C Git global config on Windows.
  * The APIs for writing and reading individual index entries have changed
    to handle lists of (name, entry) tuples rather than tuples.
* Tue May 18 2021 dmueller@suse.com
- update to 0.20.21:
  * Add basic support for a GcsObjectStore that stores
    pack files in gcs.
  * In porcelain.push, default to local active branch.
  * Support fetching symrefs.
* Thu Apr 22 2021 dmueller@suse.com
- update to 0.20.20:
  * Support untracked symlinks to paths outside the
    repository.
  * Fix handling of negative matches in nested gitignores.
  * Fix formatting in setup.py. (Jelmer Vernooĳ)
  * Add release configuration. (Jelmer Vernooĳ)
  * credentials: ignore end-of-line character. (Georges Racinet)
  * Fix failure in get_untracked_paths when the repository contains symlinks.
  * docs: Clarify that Git objects are created on `git add`.
  * Add flag to only attempt to fetch ignored untracked files when specifically requested.
* Tue Dec 29 2020 dmueller@suse.com
- update to 0.20.15:
  * Add some functions for parsing and writing bundles.
  * Add ``no_verify`` flag to ``porcelain.commit`` and ``Repo.do_commit``.
  * Remove dependency on external mock module.
- drop remove_mock.patch (upstream)
* Sun Dec 20 2020 dmueller@suse.com
- update to 0.20.14:
  * Fix some stash functions on Python 3.
  * Fix handling of relative paths in alternates files on Python 3.
  * Add py.typed to allow type checking.
  * Add tests demonstrating a bug in the walker code.
* Mon Dec 14 2020 code@bnavigator.de
- Fix condition around BuildRequirement
* Sun Dec 13 2020 mcepl@suse.com
- We don't need to break Python 2.7
* Fri Dec 11 2020 mcepl@suse.com
- Add remove_mock.patch to remove dependency on the external mock
  package (gh#dulwich/dulwich#820).
* Tue Nov 10 2020 dmueller@suse.com
- update to 0.20.11:
  * Fix wheels build on Linux. (Ruslan Kuprieiev)
  * Enable wheels build for Python 3.9 on Linux. (Jelmer Vernooĳ)
  * Check core.repositoryformatversion. (Jelmer Vernooĳ, #803)
  * Fix ACK/NACK handling in archive command handling in dulwich.client.
* Wed Sep 16 2020 dmueller@suse.com
- update to 0.20.6:
  * Add a ``RefsContainer.watch`` interface.
  * Fix pushing of new branches from porcelain.push.
  * Honor shallows when pushing from a shallow clone.
  * Fix porcelain.path_to_tree_path for Python 3.5.
* Fri Jul 10 2020 dmueller@suse.com
- update to 0.20.5:
  * Print a clearer exception when setup.py is executed on Python < 3.5.
  * Send an empty pack to clients if they requested objects, even if they
    already have those objects. Thanks to Martijn Pieters for
    the detailed bug report.
  * porcelain.pull: Don't ask for objects that we already have.
  * Add LCA implementation. (Kevin Hendricks)
  * Add functionality for finding the merge base. (Kevin Hendricks)
  * Check for diverged branches during push.
  * Check for fast-forward during pull. (Jelmer Vernooĳ, #666)
  * Return a SendPackResult object from
    GitClient.send_pack(). (Jelmer Vernooĳ)
  * ``GitClient.send_pack`` now sets the ``ref_status`` attribute
    on its return value to a dictionary mapping ref names
    to error messages. Previously, it raised UpdateRefsError
    if any of the refs failed to update.
    (Jelmer Vernooĳ, #780)
  * Add a ``porcelain.Error`` object that most errors in porcelain
    derive from. (Jelmer Vernooĳ)
  * Fix argument parsing in dulwich command-line app.
    (Jelmer Vernooĳ, #784)
  * Add support for remembering remote refs after push/pull.
    (Jelmer Vernooĳ, #752)
  * Support passing tree and output encoding to
    dulwich.patch.unified_diff. (Jelmer Vernooĳ, #763)
  * Fix pushing of new refs over HTTP(S) when there are
    no new objects to be sent.
    (Jelmer Vernooĳ, #739)
  * Raise new error HTTPUnauthorized when the server sends
    back a 401. The client can then retry with credentials.
    (Jelmer Vernooĳ, #691)
  * Move the guts of bin/dulwich to dulwich.cli, so it is easier to
    test or import. (Jelmer Vernooĳ)
  * Install dulwich script from entry_points when setuptools is available,
    making it slightly easier to use on Windows. (Jelmer Vernooĳ, #540)
  * Set python_requires>=3.5 in setup.py. (Manuel Jacob)
* Mon Jun  8 2020 dmueller@suse.com
- update to 0.20.2:
  * Brown bag release to fix uploads of Windows wheels.
  * Publish binary wheels for: Windows, Linux, Mac OS X.
    (Jelmer Vernooĳ, #711, #710, #629)
  * Drop support for Python 2. (Jelmer Vernooĳ)
  * Only return files from the loose store that look like git objects.
  * Ignore agent= capability if sent by client.
  * Don't break when encountering block devices.
  * Decode URL paths in HttpGitClient using utf-8 rather than file system
  * Fix pushing from a shallow clone.
  * Don't send "deepen None" to server if graph walker
    supports shallow. (Jelmer Vernooĳ, #747)
  * Support tweaking the compression level for
    loose objects through the "core.looseCompression" and
    "core.compression" settings. (Jelmer Vernooĳ)
  * Support tweaking the compression level for
    pack objects through the "core.packCompression" and
    "core.compression" settings. (Jelmer Vernooĳ)
  * Add a "dulwich.contrib.diffstat" module.
    (Kevin Hendricks)
* Tue Mar 31 2020 tchvatal@suse.com
- Do not remove the tests from distdir as other pkgs can import
  them
* Fri Feb 28 2020 dmueller@suse.com
- update to 0.19.15:
  * Properly handle files that are just executable for the
    current user. (Jelmer Vernooĳ, #734)
  * Fix handling of stored encoding in
    ``dulwich.porcelain.get_object_by_path`` on Python 3.
    (Jelmer Vernooĳ)
  * Support the include_trees and rename_detector arguments
    at the same time when diffing trees.
    (Jelmer Vernooĳ)
  * Strip superfluous <> around email. (monnerat)
  * Stop checking for ref validity client-side. Users can
    still call check_wants manually. (Jelmer Vernooĳ)
  * Switch over to Google-style docstrings.
  * Add a ``dulwich.porcelain.active_branch`` function.
  * Cleanup new directory if clone fails. (Jelmer Vernooĳ, #733)
  * Expand "~" in global exclude path. (Jelmer Vernooĳ)
* Fri Sep 13 2019 tchvatal@suse.com
- Update to 0.19.13:
  * Don't trust modes if they can't be modified after a file has been created.
  * Implement ``RefsContainer.__iter__``
  * Mark ``.git`` directories as hidden on Windows.
  * Return a 404 not found error when repository is not found.
  * Add a basic ``porcelain.clean``.
  * Update directory detection for `get_unstaged_changes` for Python 3.
  * Avoid ``PermissionError``, since it is Python3-specific.
* Fri Apr 26 2019 tbechtold@suse.com
- Use Recommends for python-gpg and python-fastimport. Both are
  optional requirements
* Thu Mar 14 2019 tchvatal@suse.com
- Update to 0.19.11:
  * too many changes to enumerate, see NEWS
- Drop docu subpackage as it needs many more sphinx modules
* Mon Nov  6 2017 rjschwei@suse.com
- Update to version 0.18.5 (bsc#1066430)
  + CVE-2017-16228
  + No detailed upstream release notes
  + Commit history https://www.dulwich.io/code/dulwich/
* Sun Sep 17 2017 bwiedemann@suse.com
- Drop environment.pickle from doc to make build reproducible
* Wed Aug  9 2017 tbechtold@suse.com
- switch to singlespec
- split documentation into extra package
* Wed Aug  9 2017 tbechtold@suse.com
- update to 0.17.3:
  * List Python 3.3 as supported. (Jelmer Vernooĳ, #513)
- Remove source validation (not working)
* Mon May  1 2017 develop7@develop7.info
- update to 0.17.2
  * BUG FIXES
    + Add workaround for
    https://bitbucket.org/pypy/pypy/issues/2499/cpyext-pystring_asstring-doesnt-work,
    fixing Dulwich when used with C extensions on pypy < 5.6. (Victor Stinner)
    + Properly quote config values with a ‘#’ character in them.
    (Jelmer Vernooij, #511)
- update to 0.17.1
  * IMPROVEMENTS
    + Add basic ‘dulwich pull’ command. (Jelmer Vernooĳ)
  * BUG FIXES
    + Cope with existing submodules during pull. (Jelmer Vernooĳ, #505)
- update to 0.17.0
  * TEST FIXES
    + Skip test that requires sync to synchronize filesystems if os.sync is not
    available. (Koen Martens)
  * IMPROVEMENTS
    + Implement MemoryRepo.{set_description,get_description}. (Jelmer Vernooĳ)
    + Raise exception in Repo.stage() when absolute paths are passed in. Allow
    passing in relative paths to porcelain.add().(Jelmer Vernooij)
  * BUG FIXES
    + Handle multi-line quoted values in config files. (Jelmer Vernooĳ, #495)
    + Allow porcelain.clone of repository without HEAD. (Jelmer Vernooĳ, #501)
    + Support passing tag ids to Walker()’s include argument. (Jelmer Vernooĳ)
    + Don’t strip trailing newlines from extra headers. (Nicolas Dandrimont)
    + Set bufsize=0 for subprocess interaction with SSH client. Fixes hangs on
    Python 3. (René Stern, #434)
    + Don’t drop first slash for SSH paths, except for those starting with “~”.
    (Jelmer Vernooij, René Stern, #463)
    + Properly log off after retrieving just refs. (Jelmer Vernooij)
- source verfication added
* Mon Jan 30 2017 rjschwei@suse.com
- Include in SLE 12 (bsc#1002895, FATE#321630)
* Wed Jan 18 2017 dmueller@suse.com
- update to 0.16.3:
  IMPROVEMENTS
  * Fixed failing test-cases on windows.
    (Koen Martens)
  * Add support for worktrees. See `git-worktree(1)` and
    `gitrepository-layout(5)`. (Laurent Rineau)
  * Add support for `commondir` file in Git control
    directories. (Laurent Rineau)
  * Add support for passwords in HTTP URLs.
    (Jon Bain, Mika Mäenpää)
  * Add `release_robot` script to contrib,
    allowing easy finding of current version based on Git tags.
    (Mark Mikofski)
  * Add ``Blob.splitlines`` method.
    (Jelmer Vernooij)
  * Add `dulwich.config.parse_submodules` function.
  * Add `RefsContainer.follow` method. (#438)
  * Support `ssh://` URLs in get_transport_and_path_from_url().
    (Jelmer Vernooĳ, #402)
  * Support missing empty line after headers in Git commits and tags.
    (Nicolas Dandrimont, #413)
  * Fix `dulwich.porcelain.status` when used in empty trees.
    (Jelmer Vernooĳ, #415)
  * Return copies of objects in MemoryObjectStore rather than
    references, making the behaviour more consistent with that of
    DiskObjectStore. (Félix Mattrat, Jelmer Vernooĳ)
  * Fix ``dulwich.web`` on Python3. (#295, Jonas Haag)
  * Many bugfixes, see NEWS file for details
  CHANGES
  * Changed license from "GNU General Public License, version 2.0 or later"
    to "Apache License, version 2.0 or later or GNU General Public License,
    version 2.0 or later". (#153)
* Mon Aug 15 2016 toddrme2178@gmail.com
- Fix update-alternatives implementation.
* Thu Jan 14 2016 toddrme2178@gmail.com
- Update to 0.12.0
  + IMPROVEMENTS
  * Add a `dulwich.archive` module that can create tarballs.
    Based on code from Jonas Haag in klaus.
  * Add a `dulwich.reflog` module for reading and writing reflogs.
    (Jelmer Vernooij)
  * Fix handling of ambiguous refs in `parse_ref` to make
    it match the behaviour described in https://git-scm.com/docs/gitrevisions.
    (Chris Bunney)
  * Support Python3 in C modules. (Lele Gaifax)
  + BUG FIXES
  * Simplify handling of SSH command invocation.
    Fixes quoting of paths. Thanks, Thomas Liebetraut. (#384)
  * Fix inconsistent handling of trailing slashes for DictRefsContainer. (#383)
  * Add hack to support thin packs duing fetch(), albeit while requiring the
    entire pack file to be loaded into memory. (jsbain)
  + CHANGES
  * This will be the last release to support Python 2.6.
- Implement update-alternatives
* Sat Dec  5 2015 termim@gmail.com
- update to 0.11.2
  + IMPROVEMENTS
  * Add support for agent= capability. (Jelmer Vernooij, #298)
  * Add support for quiet capability. (Jelmer Vernooij)
  + BUG FIXES
  * The ParamikoSSHVendor class has been moved to
    dulwich.contrib.paramiko_vendor, as it’s currently untested.
    (Jelmer Vernooij, #364)
- update to 0.11.1 2015-09-13
  * Fix-up release to exclude broken blame.py file.
- update to 0.11.0 2015-09-13
  + IMPROVEMENTS
  * Extended Python3 support to most of the codebase. (Gary van der
    Merwe, Jelmer Vernooij)
  * The Repo object has a new close method that can be called to close
    any open resources. (Gary van der Merwe)
  * Support ‘git.bat’ in SubprocessGitClient on Windows. (Stefan
    Zimmermann)
  * Advertise ‘ofs-delta’ capability in receive-pack server side
    capabilities. (Jelmer Vernooij)
  * Switched default_local_git_client_cls to LocalGitClient. (Gary van
    der Merwe)
  * Add porcelain.ls_remote and GitClient.get_refs. (Michael Edgar)
  * Add Repo.discover method. (B. M. Corser)
  * Add dulwich.objectspec.parse_refspec. (Jelmer Vernooij)
  * Add porcelain.pack_objects and porcelain.repack. (Jelmer Vernooij)
  + BUG FIXES
  * Fix handling of ‘done’ in graph walker and implement the ‘no-done’
    capability. (Tommy Yu, #88)
  * Avoid recursion limit issues resolving deltas. (William Grant, #81)
  * Allow arguments in local client binary path overrides. (Jelmer
    Vernooij)
  * Fix handling of commands with arguments in paramiko SSH
    client. (Andreas Klöckner, Jelmer Vernooij, #363)
  * Fix parsing of quoted strings in configs. (Jelmer Vernooij, #305)
* Tue May 12 2015 termim@gmail.com
- update to version 0.10.1
  + BUG FIXES
  * Return `ApplyDeltaError` when encountering delta errors
    in both C extensions and native delta application code.
    (Jelmer Vernooij, #259)
- update to version 0.10.0
  + BUG FIXES
  * In dulwich.index.build_index_from_tree, by default
    refuse to create entries that start with .git/.
  * Fix running of testsuite when installed.
    (Jelmer Vernooij, #223)
  * Use a block cache in _find_content_rename_candidates(),
    improving performance. (Mike Williams)
  * Add support for ``core.protectNTFS`` setting.
    (Jelmer Vernooij)
  * Fix TypeError when fetching empty updates.
    (Hwee Miin Koh)
  * Resolve delta refs when pulling into a MemoryRepo.
    (Max Shawabkeh, #256)
  * Fix handling of tags of non-commits in missing object finder.
    (Augie Fackler, #211)
  * Explicitly disable mmap on plan9 where it doesn't work.
    (Jeff Sickel)
  + IMPROVEMENTS
  * New public method `Repo.reset_index`. (Jelmer Vernooij)
  * Prevent duplicate parsing of loose files in objects
    directory when reading. Thanks to David Keijser for the
    report. (Jelmer Vernooij, #231)
- update to version 0.9.9
  + SECURITY BUG FIXES
  * Fix buffer overflow in C implementation of pack apply_delta().
    (CVE-2015-0838)
    Thanks to Ivan Fratric of the Google Security Team for
    reporting this issue.
    (Jelmer Vernooij)
* Sun Feb 22 2015 develop7@develop7.info
- update to version 0.9.8
  + disabled tests
- Changes from 0.9.7
  + BUG FIXES
  * Various fixes to improve test suite running on Windows.
    (Gary van der Merwe)
  * Limit delta copy length to 64K in v2 pack files. (Robert Brown)
  * Strip newline from final ACKed SHA while fetching packs.
    (Michael Edgar)
  * Remove assignment to PyList_SIZE() that was causing segfaults on
    pypy. (Jelmer Vernooij, #196)
  + IMPROVEMENTS
  * Add porcelain 'receive-pack' and 'upload-pack'. (Jelmer Vernooij)
  * Handle SIGINT signals in bin/dulwich. (Jelmer Vernooij)
  * Add 'status' support to bin/dulwich. (Jelmer Vernooij)
  * Add 'branch_create', 'branch_list', 'branch_delete' porcelain.
    (Jelmer Vernooij)
  * Add 'fetch' porcelain. (Jelmer Vernooij)
  * Add 'tag_delete' porcelain. (Jelmer Vernooij)
  * Add support for serializing/deserializing 'gpgsig' attributes in Commit.
    (Jelmer Vernooij)
  + CHANGES
  * dul-web is now available as 'dulwich web-daemon'.
    (Jelmer Vernooij)
  * dulwich.porcelain.tag has been renamed to tag_create.
    dulwich.porcelain.list_tags has been renamed to tag_list.
    (Jelmer Vernooij)
  + API CHANGES
  * Restore support for Python 2.6. (Jelmer Vernooij, Gary van der Merwe)
- Changes from 0.9.6
  + BUG FIXES
  * Fix tests dependent on hash ordering. (Michael Edgar)
  * Support staging symbolic links in Repo.stage.
    (Robert Brown)
  * Ensure that all files object are closed when running the test suite.
    (Gary van der Merwe)
  * When writing OFS_DELTA pack entries, write correct offset.
    (Augie Fackler)
  * Fix handler of larger copy operations in packs. (Augie Fackler)
  * Various fixes to improve test suite running on Windows.
    (Gary van der Merwe)
  * Fix logic for extra adds of identical files in rename detector.
    (Robert Brown)
  + IMPROVEMENTS
  * Add porcelain 'status'. (Ryan Faulkner)
  * Add porcelain 'daemon'. (Jelmer Vernooij)
  * Add `dulwich.greenthreads` module which provides support
    for concurrency of some object store operations.
    (Fabien Boucher)
  * Various changes to improve compatibility with Python 3.
    (Gary van der Merwe, Hannu Valtonen, michael-k)
  * Add OpenStack Swift backed repository implementation
    in dulwich.contrib. See README.swift for details. (Fabien Boucher)
  + API CHANGES
  * An optional close function can be passed to the Protocol class. This will
    be called by its close method. (Gary van der Merwe)
  * All classes with close methods are now context managers, so that they can
    be easily closed using a `with` statement. (Gary van der Merwe)
  * Remove deprecated `num_objects` argument to `write_pack` methods.
    (Jelmer Vernooij)
  + OTHER CHANGES
  * The 'dul-daemon' script has been removed. The same functionality
    is now available as 'dulwich daemon'. (Jelmer Vernooij)
- Changes from 0.9.5
  + IMPROVEMENTS
  * Add support for recursive add in 'git add'.
    (Ryan Faulkner, Jelmer Vernooij)
  * Add porcelain 'list_tags'. (Ryan Faulkner)
  * Add porcelain 'push'. (Ryan Faulkner)
  * Add porcelain 'pull'. (Ryan Faulkner)
  * Support 'http.proxy' in HttpGitClient.
    (Jelmer Vernooij, #1096030)
  * Support 'http.useragent' in HttpGitClient.
    (Jelmer Vernooij)
  * In server, wait for clients to send empty list of
    wants when talking to empty repository.
    (Damien Tournoud)
  * Various changes to improve compatibility with
    Python 3. (Gary van der Merwe)
  + BUG FIXES
  * Support unseekable 'wsgi.input' streams.
    (Jonas Haag)
  * Raise TypeError when passing unicode() object
    to Repo.__getitem__.
    (Jonas Haag)
  * Fix handling of `reset` command in dulwich.fastexport.
    (Jelmer Vernooij, #1249029)
  * In client, don't wait for server to close connection
    first. Fixes hang when used against GitHub
    server implementation. (Siddharth Agarwal)
  * DeltaChainIterator: fix a corner case where an object is inflated as an
    object already in the repository.
    (Damien Tournoud, #135)
  * Stop leaking file handles during pack reload. (Damien Tournoud)
  * Avoid reopening packs during pack cache reload. (Jelmer Vernooij)
  + API CHANGES
  * Drop support for Python 2.6. (Jelmer Vernooij)
- Changes from 0.9.4
  + IMPROVEMENTS
  * Add porcelain 'tag'. (Ryan Faulkner)
  * New module `dulwich.objectspec` for parsing strings referencing
    objects and commit ranges. (Jelmer Vernooij)
  * Add shallow branch support. (milki)
  * Allow passing urllib2 `opener` into HttpGitClient.
    (Dov Feldstern, #909037)
  + CHANGES
  * Drop support for Python 2.4 and 2.5. (Jelmer Vernooij)
  + API CHANGES
  * Remove long deprecated ``Repo.commit``, ``Repo.get_blob``,
    ``Repo.tree`` and ``Repo.tag``. (Jelmer Vernooij)
  * Remove long deprecated ``Repo.revision_history`` and ``Repo.ref``.
    (Jelmer Vernooij)
  * Remove long deprecated ``Tree.entries``. (Jelmer Vernooij)
  + BUG FIXES
  * Raise KeyError rather than TypeError when passing in
    unicode object of length 20 or 40 to Repo.__getitem__.
    (Jelmer Vernooij)
  * Use 'rm' rather than 'unlink' in tests, since the latter
    does not exist on OpenBSD and other platforms.
    (Dmitrij D. Czarkoff)
- Changes from 0.9.3
  + IMPROVEMENTS
  * Add ssh_kwargs attribute to ParamikoSSHVendor. (milki)
  * Add Repo.set_description(). (Víðir Valberg Guðmundsson)
  * Add a basic `dulwich.porcelain` module. (Jelmer Vernooij, Marcin Kuzminski)
  * Various performance improvements for object access.
    (Jelmer Vernooij)
  * New function `get_transport_and_path_from_url`,
    similar to `get_transport_and_path` but only
    supports URLs.
    (Jelmer Vernooij)
  * Add support for file:// URLs in `get_transport_and_path_from_url`.
    (Jelmer Vernooij)
  * Add LocalGitClient implementation.
    (Jelmer Vernooij)
  + BUG FIXES
  * Support filesystems with 64bit inode and device numbers.
    (André Roth)
  + CHANGES
  * Ref handling has been moved to dulwich.refs.
    (Jelmer Vernooij)
  + API CHANGES
  * Remove long deprecated RefsContainer.set_ref().
    (Jelmer Vernooij)
  * Repo.ref() is now deprecated in favour of Repo.refs[].
    (Jelmer Vernooij)
  + FEATURES
  * Add support for graftpoints. (milki)
* Fri Nov  1 2013 p.drouand@gmail.com
- Fix download Url
* Fri Nov  1 2013 p.drouand@gmail.com
- Update to version 0.9.3
  + * Fix path for stdint.h in MANIFEST.in.
- Changes from version 0.9.2
  + Include stdint.h in MANIFEST.in
- Changes from version 0.9.1
  + Support lookups of 40-character refs in BaseRepo.__getitem_
  + Fix fetching packs with side-band-64k capability disabled.
  + Several fixes in send-pack protocol behaviour - handling of empty
    pack files and deletes. #1063087
  + Fix capability negotiation when fetching packs over HTTP.
    [#1072461]
  + Enforce determine_wants returning an empty list rather than None.
  + In the server, support pushes just removing refs.
  + Support passing a single revision to BaseRepo.get_walker() rather
    than a list of revisions.
  + Add `Repo.get_description` method.
  + Support thin packs in Pack.iterobjects() and Pack.get_raw().
  + Add `MemoryObjectStore.add_pack` and `MemoryObjectStore.add_thin_pack` methods.
  + Add paramiko-based SSH vendor.
  + Support running 'dulwich.server' and 'dulwich.web' using 'python -m'.
  + Add ObjectStore.close().
  + Raise appropriate NotImplementedError when encountering dumb HTTP servers.
  + SSHVendor.connect_ssh has been renamed to SSHVendor.run_command.
  + ObjectStore.add_pack() now returns a 3-tuple. The last element will be an
    abort() method that can be used to cancel the pack operation.
- Changes from version 0.9.0
  + Push efficiency - report missing objects only. #562676
  + Use indentation consistent with C Git in config files.
    [#1031356]
  + Recognize and skip binary files in diff function.
  + Fix handling of relative paths in dulwich.client.get_transport_and_path.
  + Preserve ordering of entries in configuration.
  + Support ~ expansion in SSH client paths. #1083439
  + Support relative paths in alternate paths.
    [#1175007]
  + Log all error messages from wsgiref server to the logging module. This
    makes the test suit quiet again.
  + Support passing None for empty tree in changes_from_tree.
  + Support fetching empty repository in client. #1060462
  + Add optional honor_filemode flag to build_index_from_tree.
  + Support core/filemode setting when building trees.
  + Add chapter on tags in tutorial
  + Add support for mergetags. #963525
  + Add support for posix shell hooks.
- Changes from 0.8.7
  + Fix use of alternates in ``DiskObjectStore``.{__contains__,__iter__}.
  + Fix compatibility with Python 2.4.
* Fri Nov 23 2012 saschpe@suse.de
- Update to version 0.8.6:
  + dulwich.__init__ no longer imports client, protocol, repo and
    server modules. (Jelmer Vernooij)
  + ConfigDict now behaves more like a dictionary.
    (Adam 'Cezar' Jenkins, issue #58)
  + HTTPGitApplication now takes an optional
    fallback_app argument. (Jonas Haag, issue #67)
  + Support for large pack index files. (Jameson Nash)
  + Make index entry tests a little bit less strict, to cope with
    slightly different behaviour on various platforms.
    (Jelmer Vernooij)
  + setup.py test (available when setuptools is installed) now
    runs all tests, not just the basic unit tests.
    (Jelmer Vernooij)
  + Commit._deserialize now actually deserializes the current state rather than
    the previous one. (Yifan Zhang, issue #59)
  + Handle None elements in lists of TreeChange objects. (Alex Holmes)
  + Support cloning repositories without HEAD set.
    (D-Key, Jelmer Vernooij, issue #69)
  + Support MemoryRepo.get_config. (Jelmer Vernooij)
  + In get_transport_and_path, pass extra keyword arguments on to
    HttpGitClient. (Jelmer Vernooij)
- Changes from version 0.8.5:
  + Avoid use of 'with' in dulwich.index. (Jelmer Vernooij)
  + Be a little bit strict about OS behaviour in index tests.
    Should fix the tests on Debian GNU/kFreeBSD. (Jelmer Vernooij)
- See NEWS file for more changes
* Tue Sep 20 2011 saschpe@suse.de
- Update to version 0.8.0:
  * web: Use correct result MIME types.
  * pack: Cache binary SHA of unpacked objects.
  - See upstream git for more details...
* Sun Jul  3 2011 saschpe@gmx.de
- Update to version 0.7.1:
  * Documentation udated
  * Tree.entries deprecated
* Thu Mar 31 2011 saschpe@suse.de
- Removed *.egg-info from %%%%files section
* Tue Jan 25 2011 saschpe@gmx.de
- Update to 0.7.0
- Packaged documentation
- Added license header
* Wed Sep  8 2010 nix@opensuse.org
- Update to 0.6.1
